import subprocess
import os
import sys
import getpass
import requests
import json
import sys

def run():
    if sys.platform != 'darwin':
        print('This program works on macOS only.')
        return 1
    print(sys.argv)
    data_url = 'https://raw.githubusercontent.com/thy2134/MacSAFER/master/plugins.json'
    json_datas = requests.get(data_url)
    if json_datas.status_code != 200:
        print('Error fetching plugin data!')
        print('URL =>', data_url)
        exit(1)
    knownPlugins, customDeleteFiles = None, None
    try:
        json_data = json.loads(json_datas.text)
        customDeleteFiles = json_data['customDeleteFiles']
        knownPlugins = json_data['knownPlugins']
    except:
        print('Error while loading data!')
        print('Response data =>')
        print(json_datas.text)
        exit(1)
    
    loaded = {
        'App': {},
        'File': {}
    }


    p = subprocess.Popen(['whoami'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    whoami = p.stdout.readline().decode('utf-8')
    is_root = (whoami == 'root\n')

    password = ''
    if not is_root:
        password = getpass.getpass('Password:')
        echo = subprocess.Popen(['echo', password], stdout=subprocess.PIPE).stdin
        (out, err) = subprocess.Popen(['sudo', '-S', 'ls'], stdin=echo, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
        if len(err) > 0:
            print('Authentication failed')
            return 1

    for key in knownPlugins.keys():
        if os.path.exists(knownPlugins[key]):
            loaded['App'][key] = knownPlugins[key]
        
    for key in customDeleteFiles:
        for item in customDeleteFiles[key]:
            if os.path.exists(item):
                if key not in loaded['File'].keys():
                    loaded['File'][key] = []
                loaded['File'][key].append(item)

    count = len(loaded['App'].keys()) + len(loaded['File'].keys())
    print('Found', count, 'software' + ('s' if count > 1 else ''))
    if count <= 0:
        return 0
    for (key, value) in loaded['App'].items():
        print(key, '=>', value)

    for (key, value) in loaded['File'].items():
        for item in value:
            print(key, '=>', item)

    yn = input('Deleting ' + str(count) + ' items. Continue? [Y/n]')
    if yn != '' and yn != 'Y':
        print('Aborting...')
        return 0

    for (key, value) in loaded['App'].items():
        print('Deleting', key)
        echo = subprocess.Popen(['echo', password], stdout=subprocess.PIPE).stdin
        p = subprocess.Popen(['sudo', '-S', value], stdin=echo, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        p.wait()


    for (key, value) in loaded['File'].items():
        for item in value:
            print('Deleting', key, 'at', item)
            echo = subprocess.Popen(['echo', password], stdout=subprocess.PIPE).stdin
            p = subprocess.Popen(['sudo', '-S', "rm", "-rf", item], stdin=echo, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            p.wait()



from setuptools import setup, find_packages

setup(name='MacSAFER',
    version='1.2',
    url='https://github.com/thy2134/MacSAFER',
    license='GPLv3',
    author='Kyujin Cho',
    author_email='thy2134@gmail.com',
    description='Delete malicious plugins from korean e-commerce, government, online banking websites to make your mac clean.',
    python_requires='>=3',
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Utilities',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 3.6',
        'Environment :: MacOS X',
        'Environment :: Console'
    ],
    packages=find_packages(exclude=['test', 'doc']),
    zip_safe=False,
    entry_points= {
        'console_scripts': ['macsafer=macsafer.command_line:main']
    }
)